package com.diagbot.facade;

import com.diagbot.dto.ProductAuthProgressDTO;
import com.diagbot.dto.WaitExamOrderCouDTO;
import com.diagbot.entity.LantoneProduct;
import com.diagbot.entity.OrderDetails;
import com.diagbot.entity.ProductOrder;
import com.diagbot.enums.VisibleIdTypeEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.idc.VisibleIdCreater;
import com.diagbot.service.impl.ProductOrderServiceImpl;
import com.diagbot.util.DateUtil;
import com.diagbot.util.UserUtils;
import com.diagbot.vo.AddOrderVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
 * 订单业务
 * @author Administrator
 *
 */
@Component
public class ProductOrderFacade extends ProductOrderServiceImpl {
	@Autowired
	private VisibleIdCreater visibleIdCreater;
	@Autowired
	private OrderDetailsFacade orderDetailsFacade;
	@Autowired
	private ServiceInfoFacade serviceInfoFacade;
	@Autowired
	private LantoneProductFacade lantoneProductFacade;
	@Autowired
	private ProductServiceFacade productServiceFacade;

	public List<ProductAuthProgressDTO> productAuthProgress(){
		List<ProductAuthProgressDTO> retList = new ArrayList<ProductAuthProgressDTO>();
		Long userId = Long.parseLong(UserUtils.getCurrentPrincipleID());
		List<ProductOrder> orderList = baseMapper.getUserProductOrder(userId);
		for(ProductOrder i : orderList){
			ProductAuthProgressDTO productAuthProgressDTO = new ProductAuthProgressDTO();
			productAuthProgressDTO.setNum(i.getNum());
			productAuthProgressDTO.setProducts(baseMapper.getOrderDetails(i.getNum()));
			retList.add(productAuthProgressDTO);
		}

		return retList;
	}

	/**
	 * @Description: 根据用户选择的产品生成订单
	 * @Author: wangyu
	 * @Date: 19:59 2018/9/18
	 */
	@Transactional
	public Boolean addOrders(AddOrderVO addOrderVO){
		Long userId = Long.parseLong(UserUtils.getCurrentPrincipleID());
		ProductOrder productOrder =new ProductOrder();
		productOrder.setCreator(UserUtils.getCurrentPrincipleID());
		productOrder.setGmtCreate(DateUtil.now());
		String orderNum = visibleIdCreater.getNextId(VisibleIdTypeEnum.IS_ORDER.getKey()).toString();
		productOrder.setNum(orderNum);
		productOrder.setUserId(userId);
		productOrder.setTime(DateUtil.now());
		if(!save(productOrder)){
			throw new CommonException(CommonErrorCode.SERVER_IS_ERROR,"添加订单失败");
		}
		for (Long o:addOrderVO.getProductId()) {
			LantoneProduct lantoneProduct = lantoneProductFacade.selectLanProduct(o);
			if(null==lantoneProduct){
				throw new CommonException(CommonErrorCode.SERVER_IS_ERROR,"获取产品信息失败:"+o);
			}
			OrderDetails orderDetails =new OrderDetails();
			orderDetails.setUserId(userId);
			orderDetails.setOrderNum(orderNum);
			orderDetails.setGmtCreate(DateUtil.now());
			orderDetails.setCreator(UserUtils.getCurrentPrincipleID());
			orderDetails.setProductId(o);
			orderDetailsFacade.save(orderDetails);
		}
		return true;
	}

	/**
	 * @Description:  根据订单号查询订单信息
	 * @Author: wangyu
	 * @Date: 19:42 2018/9/20
	 */
	public ProductOrder selectByOrderNum(ProductOrder productOrder){
		return selctOrderTimeByOrderNum(productOrder);
	}
	
	
    public WaitExamOrderCouDTO waitExamOrderCou(){
    	WaitExamOrderCouDTO waitExamOrderCouDTO = new WaitExamOrderCouDTO();
    	waitExamOrderCouDTO.setCount(baseMapper.waitExamOrderCou());
    	return waitExamOrderCouDTO;
    }
	
}


